@@ -1,23 +1,17 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2005 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2005 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2005-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2005 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2005 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2005-2008 Eike Hein <hein@kde.org>
 */
 
 #include "config/preferences.h"
 #include "ignore.h"
 #include "highlight.h"
 
-#include <QFileInfo>
 #include <QHashIterator>
 #include <QHeaderView>
 #include <QTreeView>
@@ -55,10 +49,11 @@ Preferences::Preferences()
     mIdentity->setIdent(user.loginName());
     mIdentity->setRealName(user.property(KUser::FullName).toString());
 
-    QStringList nickList;
-    nickList.append(user.loginName());
-    nickList.append(user.loginName() + QLatin1Char('_'));
-    nickList.append(user.loginName() + QStringLiteral("__"));
+    const QStringList nickList = {
+        user.loginName(),
+        user.loginName() + QLatin1Char('_'),
+        user.loginName() + QStringLiteral("__"),
+    };
     mIdentity->setNicknameList(nickList);
 
     Konversation::ServerGroupSettingsPtr serverGroup(new Konversation::ServerGroupSettings);
@@ -90,14 +85,16 @@ const Konversation::ServerGroupHash Preferences::serverGroupHash()
 
 const QStringList Preferences::defaultQuickButtonList()
 {
-    return QStringList() << QStringLiteral("Op,/OP %u%n")
-                         << QStringLiteral("DeOp,/DEOP %u%n")
-                         << QStringLiteral("WhoIs,/WHOIS %s,%%u%n")
-                         << QStringLiteral("Version,/CTCP %s,%%u VERSION%n")
-                         << QStringLiteral("Kick,/KICK %u%n")
-                         << QStringLiteral("Ban,/BAN %u%n")
-                         << QStringLiteral("Part,/PART %c Leaving...%n")
-                         << QStringLiteral("Quit,/QUIT Leaving...%n");
+    return QStringList {
+        QStringLiteral("Op,/OP %u%n"),
+        QStringLiteral("DeOp,/DEOP %u%n"),
+        QStringLiteral("WhoIs,/WHOIS %s,%%u%n"),
+        QStringLiteral("Version,/CTCP %s,%%u VERSION%n"),
+        QStringLiteral("Kick,/KICK %u%n"),
+        QStringLiteral("Ban,/BAN %u%n"),
+        QStringLiteral("Part,/PART %c Leaving...%n"),
+        QStringLiteral("Quit,/QUIT Leaving...%n"),
+    };
 }
 
 const QStringList Preferences::quickButtonList()
@@ -119,10 +116,10 @@ void Preferences::clearQuickButtonList()
 
 const QList<QStringList> Preferences::defaultAutoreplaceList()
 {
-    QList<QStringList> defaultList;
-    defaultList.append(QStringList() << QStringLiteral("1") << QStringLiteral("o") << QStringLiteral("\\[\\[([^\\s]+)\\]\\]") << QStringLiteral("http://en.wikipedia.org/wiki/Special:Search?go=Go&search=%1"));
-    defaultList.append(QStringList() << QStringLiteral("1") << QStringLiteral("o") << QStringLiteral("(BUG:|bug:)([0-9]+)") << QStringLiteral("https://bugs.kde.org/show_bug.cgi?id=%2"));
-    return defaultList;
+    return QList<QStringList> {
+        { QStringLiteral("1"), QStringLiteral("o"), QStringLiteral("\\[\\[([^\\s]+)\\]\\]"), QStringLiteral("http://en.wikipedia.org/wiki/Special:Search?go=Go&search=%1") },
+        { QStringLiteral("1"), QStringLiteral("o"), QStringLiteral("(BUG:|bug:)([0-9]+)"), QStringLiteral("https://bugs.kde.org/show_bug.cgi?id=%2") },
+    };
 }
 
 const QList<QStringList> Preferences::autoreplaceList()
@@ -130,7 +127,7 @@ const QList<QStringList> Preferences::autoreplaceList()
   return self()->mAutoreplaceList;
 }
 
-void Preferences::setAutoreplaceList(const QList<QStringList> newList)
+void Preferences::setAutoreplaceList(const QList<QStringList> &newList)
 {
   self()->mAutoreplaceList=newList;
 }
@@ -163,14 +160,12 @@ const Konversation::ServerGroupSettingsPtr Preferences::serverGroupById(int id)
 const QList<Konversation::ServerGroupSettingsPtr> Preferences::serverGroupsByServer(const QString& server)
 {
     QList<Konversation::ServerGroupSettingsPtr> serverGroups;
-    QHashIterator<int, Konversation::ServerGroupSettingsPtr> it(self()->mServerGroupHash);
-    while(it.hasNext())
-    {
-        it.next();
-        for (int i=0; i != it.value()->serverList().count(); i++)
-        {
-            if(it.value()->serverByIndex(i).host().toLower() == server)
-                serverGroups.append(it.value());
+    const Konversation::ServerGroupHash& serverGroupHash = self()->mServerGroupHash;
+    for (const auto& serverGroupSettings : serverGroupHash) {
+        const auto serverList = serverGroupSettings->serverList();
+        for (const auto& serverSertting : serverList) {
+            if (serverSertting.host().toLower() == server)
+                serverGroups.append(serverGroupSettings);
         }
     }
     return serverGroups;
@@ -193,10 +188,9 @@ QList<int> Preferences::serverGroupIdsByName(const QString& serverGroup)
 
 bool Preferences::isServerGroup(const QString& server)
 {
-    QHashIterator<int, Konversation::ServerGroupSettingsPtr> it(self()->mServerGroupHash);
-    while(it.hasNext())
-    {
-        if(it.next().value()->name().toLower() == server.toLower())
+    const Konversation::ServerGroupHash& serverGroupHash = self()->mServerGroupHash;
+    for (const auto& serverGroupSettings : serverGroupHash) {
+        if (serverGroupSettings->name().toLower() == server.toLower())
             return true;
     }
     return false;
@@ -213,7 +207,7 @@ const QList<Highlight*> Preferences::highlightList()
     return self()->mHighlightList;
 }
 
-void Preferences::setHighlightList(QList<Highlight*> newList)
+void Preferences::setHighlightList(const QList<Highlight*> &newList)
 {
     qDeleteAll(self()->mHighlightList);
     self()->mHighlightList.clear();
@@ -227,7 +221,7 @@ void Preferences::addHighlight(const QString& highlight, bool regExp, const QCol
         QUrl(soundURL), autoText, chatWindows, notify));
 }
 
-void Preferences::setIgnoreList(QList<Ignore*> newList)
+void Preferences::setIgnoreList(const QList<Ignore*> &newList)
 {
     clearIgnoreList();
     self()->mIgnoreList=newList;
@@ -241,8 +235,7 @@ void Preferences::addIgnore(const QString &newIgnore)
 
 bool Preferences::removeIgnore(const QString &oldIgnore)
 {
-    foreach (Ignore *ignore, self()->mIgnoreList)
-    {
+    for (Ignore *ignore : qAsConst(self()->mIgnoreList)) {
         if (ignore->getName().toLower() == oldIgnore.toLower())
         {
             self()->mIgnoreList.removeOne(ignore);
@@ -256,8 +249,7 @@ bool Preferences::removeIgnore(const QString &oldIgnore)
 
 bool Preferences::isIgnored(const QString &nickname)
 {
-    foreach (Ignore *ignore, self()->mIgnoreList)
-    {
+    for (Ignore *ignore : qAsConst(self()->mIgnoreList)) {
         if (ignore->getName().section(QLatin1Char('!'),0,0).toLower()==nickname.toLower())
         {
             return true;
@@ -279,7 +271,7 @@ const QStringList Preferences::notifyListByGroupId(int serverGroupId)
 
 const QString Preferences::notifyStringByGroupId(int serverGroupId)
 {
-    return notifyListByGroupId(serverGroupId).join(QStringLiteral(" "));
+    return notifyListByGroupId(serverGroupId).join(QLatin1Char(' '));
 }
 
 bool Preferences::addNotify(int serverGroupId, const QString& newPattern)
@@ -304,13 +296,10 @@ bool Preferences::removeNotify(int serverGroupId, const QString& pattern)
     if (self()->mNotifyList.contains(serverGroupId))
     {
         QString lowered = pattern.toLower();
-        QStringList& oldList = self()->mNotifyList[serverGroupId];
+        const QStringList& oldList = self()->mNotifyList[serverGroupId];
         QStringList newList;
 
-        for (int i = 0; i < oldList.size(); ++i)
-        {
-            const QString& nick = oldList[i];
-
+        for (const QString& nick : oldList) {
             if (nick.toLower() != lowered)
                 newList << nick;
         }
@@ -339,8 +328,8 @@ bool Preferences::isNotify(int serverGroupId, const QString& pattern)
 }
 
 // Default identity functions
-void Preferences::addIdentity(IdentityPtr identity) { self()->mIdentityList.append(identity); }
-void Preferences::removeIdentity(IdentityPtr identity) { self()->mIdentityList.removeOne(identity); }
+void Preferences::addIdentity(const IdentityPtr &identity) { self()->mIdentityList.append(identity); }
+void Preferences::removeIdentity(const IdentityPtr &identity) { self()->mIdentityList.removeOne(identity); }
 
 void Preferences::clearIdentityList()
 {
@@ -357,17 +346,11 @@ void Preferences::setIdentityList(const IdentityList& list)
 
 const IdentityPtr Preferences::identityByName(const QString& name)
 {
-    QList<IdentityPtr> identities = identityList();
-    QList<IdentityPtr>::iterator it = identities.begin();
-
-    while(it != identities.end())
-    {
-        if((*it)->getName() == name)
-        {
-            return (*it);
+    const QList<IdentityPtr> identities = identityList();
+    for (const auto& identity : identities) {
+        if (identity->getName() == name) {
+            return identity;
         }
-
-        ++it;
     }
 
     // no self()->matching identity found, return default identity
@@ -376,16 +359,14 @@ const IdentityPtr Preferences::identityByName(const QString& name)
 
 const IdentityPtr Preferences::identityById(int id)
 {
-    QList<IdentityPtr> identList = identityList();
-    for(QList<IdentityPtr>::iterator it = identList.begin(); it != identList.end(); ++it)
-    {
-        if((*it)->id() == id)
-        {
-            return (*it);
+    const QList<IdentityPtr> identities = identityList();
+    for (const auto& identity : identities) {
+        if (identity->id() == id) {
+            return identity;
         }
     }
 
-    return identList.first();
+    return identities.first();
 }
 
 QStringList Preferences::defaultAliasList()
@@ -394,20 +375,19 @@ QStringList Preferences::defaultAliasList()
     const QStringList scriptDirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("scripts"), QStandardPaths::LocateDirectory);
     QSet<QString> scripts;
 
-    foreach(const QString &dir, scriptDirs) {
+    for (const QString &dir : scriptDirs) {
 
-        const QStringList &scriptFiles = QDir(dir).entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::Executable);
+        const QStringList scriptFiles = QDir(dir).entryList(QDir::Files | QDir::NoDotAndDotDot | QDir::Executable);
 
-        foreach(const QString &script, scriptFiles) {
+        for (const QString &script : scriptFiles) {
             scripts << script;
         }
     }
 
     QStringList aliasList;
 
-    foreach(const QString& script, scripts)
-    {
-        aliasList.append(QString("%1 /exec %1").arg(script));
+    for (const QString& script : qAsConst(scripts)) {
+        aliasList.append(QStringLiteral("%1 /exec %1").arg(script));
 
         // FIXME: Historically, defaultAliasList() is primarily used to dynamically
         // compile a list of installed scripts and generate appropriate aliases for
@@ -417,7 +397,7 @@ QStringList Preferences::defaultAliasList()
         // capability to differentiate  between audio and video media. This method
         // needs at the very least to be split up in two, or scripts may in the
         // future determine what aliases they want to add.
-        if (script == QStringLiteral("media"))
+        if (script == QLatin1String("media"))
         {
             aliasList.append(QStringLiteral("audio /exec media audio"));
             aliasList.append(QStringLiteral("video /exec media video"));
@@ -480,13 +460,11 @@ const QString Preferences::channelEncoding(const QString& server,const QString&
     //check all matching server's encodings
     //TODO when we rewrite dbus, allow for multiple encodings to be returned
     //for true 'duplicity compatibility'
-    QList<int> serverIds = serverGroupIdsByName(server);
-    QString codec;
+    const QList<int> serverIds = serverGroupIdsByName(server);
     if(serverIds.count() > 1)
     {
-        for (int i=0; i < serverIds.count(); i++)
-        {
-            codec = channelEncoding(serverIds.at(i),channel);
+        for (int serverId : serverIds) {
+            const QString codec = channelEncoding(serverId, channel);
             if(!codec.isEmpty())
                 return codec;
         }
@@ -507,11 +485,11 @@ const QString Preferences::channelEncoding(int serverGroupId,const QString& chan
 void Preferences::setChannelEncoding(const QString& server,const QString& channel,const QString& encoding)
 {
     //set channel encoding for ALL matching servergroups
-    QList<int> serverIds = serverGroupIdsByName(server);
+    const QList<int> serverIds = serverGroupIdsByName(server);
     if(serverIds.count() > 1)
     {
-        for(int i=0; i < serverIds.count(); i++)
-            setChannelEncoding(serverIds.at(i),channel,encoding);
+        for (int serverId : serverIds)
+            setChannelEncoding(serverId, channel, encoding);
     }
     else
         setChannelEncoding(serverIds.first(),channel,encoding);
@@ -532,7 +510,7 @@ const QStringList Preferences::channelEncodingsChannelList(int serverGroupId)
     return self()->mChannelEncodingsMap[serverGroupId].keys();
 }
 
-const QString Preferences::spellCheckingLanguage(Konversation::ServerGroupSettingsPtr serverGroup, const QString& key)
+const QString Preferences::spellCheckingLanguage(const Konversation::ServerGroupSettingsPtr &serverGroup, const QString& key)
 {
     if (self()->mServerGroupSpellCheckingLanguages.contains(serverGroup))
         return self()->mServerGroupSpellCheckingLanguages.value(serverGroup).value(key);
@@ -548,7 +526,7 @@ const QString Preferences::spellCheckingLanguage(const QString& server, const QS
     return QString();
 }
 
-void Preferences::setSpellCheckingLanguage(Konversation::ServerGroupSettingsPtr serverGroup, const QString& key, const QString& language)
+void Preferences::setSpellCheckingLanguage(const Konversation::ServerGroupSettingsPtr &serverGroup, const QString& key, const QString& language)
 {
     QHash<QString, QString> languageHash;
 
@@ -592,17 +570,19 @@ QString Preferences::webBrowserCmd()
 {
   // add %u to command if it's not in there
   QString cmd=self()->mWebBrowserCmd;
-  if (!cmd.contains(QStringLiteral("%u")))
+  if (!cmd.contains(QLatin1String("%u")))
       cmd += QStringLiteral(" %u");
   return cmd;
 }
 
-void Preferences::saveColumnState(QTreeView *treeView, QString name)
+void Preferences::saveColumnState(QTreeView *treeView, const QString &name)
 {
     KConfigGroup group(KSharedConfig::openConfig(), name);
 
     QList<int> columnWidths;
-    for (int i = 0; i < treeView->header()->count(); ++i)
+    const int columnCount = treeView->header()->count();
+    columnWidths.reserve(columnCount);
+    for (int i = 0; i < columnCount; ++i)
         columnWidths.append(treeView->columnWidth(i));
     // save column widths
     group.writeEntry("ColumnWidths", columnWidths);
@@ -610,7 +590,7 @@ void Preferences::saveColumnState(QTreeView *treeView, QString name)
     group.writeEntry("ColumnSortDescending", treeView->header()->sortIndicatorOrder() == Qt::DescendingOrder ? true : false );
 }
 
-void Preferences::restoreColumnState(QTreeView* treeView, QString name, int defaultColumn , Qt::SortOrder defaultSortOrder)
+void Preferences::restoreColumnState(QTreeView* treeView, const QString &name, int defaultColumn , Qt::SortOrder defaultSortOrder)
 {
     KConfigGroup group(KSharedConfig::openConfig(), name);
 
