@@ -1,15 +1,10 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2004, 2009 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2012 Eike Hein <hein@kde.org>
 */
 
-/*
-  copyright: (C) 2004, 2009 by Peter Simonsson
-  email:     peter.simonsson@gmail.com
-  Copyright (C) 2012 Eike Hein <hein@kde.org>
-*/
 #include "identitydialog.h"
 #include "application.h"
 #include "awaymanager.h"
@@ -21,12 +16,13 @@
 #include <KMessageBox>
 #include <KMessageWidget>
 #include <KUser>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <KStandardGuiItem>
 #include <QVBoxLayout>
 
+#include <algorithm>
+
 namespace Konversation
 {
 
@@ -77,7 +73,9 @@ namespace Konversation
         m_delBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
         connect(m_delBtn, &QPushButton::clicked, this, &IdentityDialog::deleteIdentity);
 
-        foreach(const IdentityPtr &id, Preferences::identityList()) {
+        const auto ids = Preferences::identityList();
+        m_identityList.reserve(ids.size());
+        for (const IdentityPtr &id : ids) {
             m_identityCBox->addItem(id->getName());
             m_identityList.append( IdentityPtr( id ) );
         }
@@ -87,11 +85,12 @@ namespace Konversation
         m_additionalAuthInfo->setCloseButtonVisible(false);
         m_additionalAuthInfo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
 
-        connect(m_authTypeCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &IdentityDialog::authTypeChanged);
-        m_authTypeCombo->addItem(i18n("Standard NickServ"), QStringLiteral("nickserv"));
-        m_authTypeCombo->addItem(i18n("Server Password"), QStringLiteral("serverpw"));
+        connect(m_authTypeCombo, QOverload<int>::of(&KComboBox::currentIndexChanged),
+                this, &IdentityDialog::authTypeChanged);
         m_authTypeCombo->addItem(i18n("SASL PLAIN"), QStringLiteral("saslplain"));
         m_authTypeCombo->addItem(i18nc("Cert = Certificate", "SASL EXTERNAL (Cert)"), QStringLiteral("saslexternal"));
+        m_authTypeCombo->addItem(i18n("Standard NickServ"), QStringLiteral("nickserv"));
+        m_authTypeCombo->addItem(i18n("Server Password"), QStringLiteral("serverpw"));
         m_authTypeCombo->addItem(i18n("SSL Client Certificate"), QStringLiteral("pemclientcert"));
 
         // add encodings to combo box
@@ -110,7 +109,8 @@ namespace Konversation
         buttonBox->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Discards all changes made"));
 
         AwayManager* awayManager = Application::instance()->getAwayManager();
-        connect(m_identityCBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &IdentityDialog::updateIdentity);
+        connect(m_identityCBox, QOverload<int>::of(&KComboBox::currentIndexChanged),
+                this, &IdentityDialog::updateIdentity);
         connect(this, &IdentityDialog::identitiesChanged, awayManager, &AwayManager::identitiesChanged);
     }
 
@@ -153,7 +153,7 @@ namespace Konversation
         m_partEdit->setText(m_currentIdentity->getPartReason());
         m_kickEdit->setText(m_currentIdentity->getKickReason());
 
-        if(index == 0)
+        if(m_identityList.count() <= 1)
         {
             m_editBtn->setEnabled(false);
             m_delBtn->setEnabled(false);
@@ -260,17 +260,17 @@ namespace Konversation
     {
         int current = m_identityCBox->currentIndex();
 
-        if(current <= 0)
+        if(m_identityList.count() <= 1)
         {
             return;
         }
 
-        ServerGroupHash serverGroups = Preferences::serverGroupHash();
-        QHashIterator<int, ServerGroupSettingsPtr> it(serverGroups);
-        bool found = false;
-
-        while (it.hasNext() && !found)
-            if (it.next().value()->identityId() == m_currentIdentity->id()) found = true;
+        const ServerGroupHash serverGroups = Preferences::serverGroupHash();
+        const int identityId = m_currentIdentity->id();
+        const bool found = std::any_of(serverGroups.begin(), serverGroups.end(),
+                                       [identityId](const ServerGroupSettingsPtr& serverGroup) {
+                                            return (serverGroup->identityId() == identityId);
+                                       });
 
         QString warningTxt;
 
@@ -288,7 +288,7 @@ namespace Konversation
             KStandardGuiItem::del()) == KMessageBox::Continue)
         {
             m_identityList.removeOne(m_currentIdentity);
-            m_currentIdentity = 0;
+            m_currentIdentity = nullptr;
             m_identityCBox->removeItem(current);
         }
     }
@@ -323,7 +323,7 @@ namespace Konversation
         m_identityCBox->setCurrentIndex(index);
     }
 
-    IdentityPtr IdentityDialog::setCurrentIdentity(IdentityPtr identity)
+    IdentityPtr IdentityDialog::setCurrentIdentity(const IdentityPtr &identity)
     {
         int index = Preferences::identityList().indexOf(identity);
         setCurrentIdentity(index);
@@ -367,11 +367,11 @@ namespace Konversation
     {
         QString authType = m_authTypeCombo->itemData(index).toString();
 
-        bool isNickServ = (authType == QStringLiteral("nickserv"));
-        bool isSaslPlain = (authType == QStringLiteral("saslplain"));
-        bool isSaslExernal = (authType == QStringLiteral("saslexternal"));
-        bool isServerPw = (authType == QStringLiteral("serverpw"));
-        bool isPemClientCert = (isSaslExernal || (authType == QStringLiteral("pemclientcert")));
+        bool isNickServ = (authType == QLatin1String("nickserv"));
+        bool isSaslPlain = (authType == QLatin1String("saslplain"));
+        bool isSaslExernal = (authType == QLatin1String("saslexternal"));
+        bool isServerPw = (authType == QLatin1String("serverpw"));
+        bool isPemClientCert = (isSaslExernal || (authType == QLatin1String("pemclientcert")));
 
         nickservNicknameLabel->setVisible(isNickServ);
         m_nickservNicknameEdit->setVisible(isNickServ);
@@ -383,7 +383,7 @@ namespace Konversation
         m_authPasswordEdit->setVisible(!isPemClientCert);
         pemClientCertFileLabel->setVisible(isPemClientCert);
         m_pemClientCertFile->setVisible(isPemClientCert);
-        m_additionalAuthInfo->setVisible(isServerPw || isPemClientCert);
+        m_additionalAuthInfo->setVisible(isNickServ || isServerPw || isPemClientCert);
 
         // Clear.
         m_saslAccountEdit->setPlaceholderText(QString());
@@ -398,13 +398,15 @@ namespace Konversation
             autoIdentifyLayout->addRow(nickservNicknameLabel, m_nickservNicknameEdit);
             autoIdentifyLayout->addRow(nickservCommandLabel, m_nickservCommandEdit);
             autoIdentifyLayout->addRow(authPasswordLabel, m_authPasswordEdit);
+            m_additionalAuthInfo->setText(i18n("NickServ may not function with auto join;  SASL is recommended."));
+            autoIdentifyLayout->addRow(nullptr, m_additionalAuthInfo);
         }
         else if (isServerPw)
         {
             autoIdentifyLayout->addRow(authPasswordLabel, m_authPasswordEdit);
 
             m_additionalAuthInfo->setText(i18n("The password entered here will override the one set in the server settings, if any."));
-            autoIdentifyLayout->addRow(0, m_additionalAuthInfo);
+            autoIdentifyLayout->addRow(nullptr, m_additionalAuthInfo);
         }
         else if (isSaslPlain)
         {
@@ -422,7 +424,7 @@ namespace Konversation
             autoIdentifyLayout->addRow(pemClientCertFileLabel, m_pemClientCertFile);
 
             m_additionalAuthInfo->setText(i18n("Certificate-based authentication forces SSL to be enabled for a connection, overriding any server settings."));
-            autoIdentifyLayout->addRow(0, m_additionalAuthInfo);
+            autoIdentifyLayout->addRow(nullptr, m_additionalAuthInfo);
         }
     }
 }
