@@ -1,23 +1,18 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005-2007 Joris Guisson <joris.guisson@gmail.com>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2005-2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
 */
 
 #ifndef KTUPNPROUTER_H
 #define KTUPNPROUTER_H
 
 #include <QHostAddress>
-
 #include <QUrl>
-#include <kjob.h>
-#include <kio/jobclasses.h>
+
+#include <KJob>
+#include <KIO/Job>
 
 namespace Konversation
 {
@@ -38,6 +33,7 @@ namespace Konversation
 
             UPnPService();
             UPnPService(const UPnPService & s);
+            ~UPnPService() = default;
 
             /**
             * Set a property of the service.
@@ -91,31 +87,6 @@ namespace Konversation
         {
             Q_OBJECT
 
-        private:
-            struct Forwarding
-            {
-                quint16 port;
-                QHostAddress host;
-                QAbstractSocket::SocketType proto;
-            };
-
-            QString server;
-            QUrl location;
-            QString uuid;
-            UPnPDeviceDescription desc;
-
-            UPnPService service;
-            QList<Forwarding*> forwards;
-
-            QHash<KJob*, UPnPService> pending_services;
-            QHash<KJob*, Forwarding*> pending_forwards;
-            QHash<KJob*, Forwarding*> pending_unforwards;
-
-            QHash<KJob*, QByteArray>  soap_data_in;
-            QHash<KJob*, QByteArray>  soap_data_out;
-
-            QString error;
-
         public:
             /**
             * Construct a router.
@@ -171,13 +142,6 @@ namespace Konversation
             /// Get the current error (null string if there is none)
             QString getError() const {return error;}
 
-        private Q_SLOTS:
-            void onRequestFinished(KJob *reply);
-            void downloadFinished(KJob* j);
-
-            void sendSoapData(KIO::Job *job, QByteArray &data);
-            void recvSoapData(KIO::Job *job, const QByteArray &data);
-
         Q_SIGNALS:
             /**
             * Signal which indicates that the XML was downloaded successfully or not.
@@ -189,10 +153,43 @@ namespace Konversation
             void forwardComplete(bool error, quint16 port);
             void unforwardComplete(bool error, quint16 port);
 
-        private:
+        private Q_SLOTS:
+            void onRequestFinished(KJob *reply);
+            void downloadFinished(KJob* j);
 
+            void sendSoapData(KIO::Job *job, QByteArray &data);
+            void recvSoapData(KIO::Job *job, const QByteArray &data);
+
+        private:
             KJob *sendSoapQuery(const QString & query,const QString & soapact,const QString & controlurl);
-            KJob *getStatusInfo(UPnPService s);
+            KJob *getStatusInfo(const UPnPService &s);
+
+        private:
+            struct Forwarding
+            {
+                quint16 port;
+                QHostAddress host;
+                QAbstractSocket::SocketType proto;
+            };
+
+            QString server;
+            QUrl location;
+            QString uuid;
+            UPnPDeviceDescription desc;
+
+            UPnPService service;
+            QList<Forwarding*> forwards;
+
+            QHash<KJob*, UPnPService> pending_services;
+            QHash<KJob*, Forwarding*> pending_forwards;
+            QHash<KJob*, Forwarding*> pending_unforwards;
+
+            QHash<KJob*, QByteArray>  soap_data_in;
+            QHash<KJob*, QByteArray>  soap_data_out;
+
+            QString error;
+
+            Q_DISABLE_COPY(UPnPRouter)
         };
     }
 }
