@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2004, 2009 Peter Simonsson <peter.simonsson@gmail.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2004, 2009 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #include "awaylabel.h"
@@ -16,7 +11,6 @@
 
 #include <QInputDialog>
 #include <KLocalizedString>
-#include <KMessageBox>
 
 AwayLabel::AwayLabel(QWidget *parent)
     : QLabel(i18n("(away)"), parent)
